@@ -1,31 +1,29 @@
 #! /usr/bin/env python
 import argparse
 
+from time import time
 from torrentmediasearcher import TorrentMediaSearcher
 
-from subtitles import get_subtitle
-from helpers import execute, daemonize
+from helpers import daemonize, set_config_dir
+from history import History
+from download import DownloadManager
 
 
 def watch(name, season=None, episode=None, sub_lang=None, serve=False,
-         quality=None, port=None):
-
+          quality=None, port=None):
 
     def get_magnet(results):
         print("Processing magnet link")
         magnet = results['magnet']
-        command = "peerflix \"%s\"" % magnet
-        if sub_lang is not None:
-            subtitle = get_subtitle(magnet, sub_lang)
-            if subtitle is not None:
-                command += " -t %s" % subtitle
-        if port is not None:#
-            command += " -p%s" % port
-        if not serve:
-            command += " --vlc"
+        manager = DownloadManager(magnet, port=port, serve=serve,
+                                  sub_lang=sub_lang)
+        manager.start()
+        set_config_dir()
 
-        print("executing command %s" % command)
-        execute(command)
+        history = History(date=int(time()), name=name, season=season,
+                          episode=episode)
+        history.save()
+        history.update()
 
     print("Searching torrent")
     search = TorrentMediaSearcher
@@ -59,8 +57,8 @@ def main():
         play_next_episode = True
         while play_next_episode:
             watch(args.name, season=args.sea_ep[0], episode=episode,
-                sub_lang=args.sub, serve=args.serve, quality=args.quality,
-                port=args.port)
+                  sub_lang=args.sub, serve=args.serve, quality=args.quality,
+                  port=args.port)
             episode += 1
             play_next_episode = args.season
 
